import { MainMenu } from '@jupyterlab/mainmenu';
import { nullTranslator } from '@jupyterlab/translation';
import { PromiseDelegate } from '@lumino/coreutils';
import { toggleFlag, updateSettings } from './commands';
export class MutableAIManager {
    constructor(options) {
        var _a;
        this._ready = new PromiseDelegate();
        this._mutableAI = null;
        this.mutableAiMainMenu = null;
        this._translator = (_a = options.translator) !== null && _a !== void 0 ? _a : nullTranslator;
        this._mainMenu = options.mainMenu;
        this._commands = options.commands;
        this._contextMenu = options.contextMenu;
        this._processFilePointer = null;
        options
            .getSettings()
            .then(mutableAI => {
            this._mutableAI = mutableAI;
            this._mutableAI.changed.connect(this._mutableAISettingsChanged, this);
            this._mutableAISettingsChanged();
            this._ready.resolve();
        })
            .catch(reason => {
            console.warn(reason);
            this._ready.reject(reason);
        });
    }
    /*
      Mutable AI manager extension enable port.
    */
    enable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', true);
    }
    /*
      Mutable AI manager extension disable port.
    */
    disable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', false);
    }
    /*
      Mutable AI manager extension initialization.
    */
    initializePlugin() {
        var _a;
        this.dispose();
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            const trans = this._translator.load('jupyterlab');
            this.mutableAiMainMenu = MainMenu.generateMenu(this._commands, {
                id: 'mutable-ai-settings',
                label: 'Mutable AI Settings',
                rank: 80
            }, trans);
            this.mutableAiMainMenu.addGroup([
                {
                    command: toggleFlag
                },
                {
                    command: updateSettings
                }
            ]);
            this._mainMenu.addMenu(this.mutableAiMainMenu, { rank: 80 });
            this._processFilePointer = this._contextMenu.addItem({
                command: 'context_menu:open',
                selector: '.jp-DirListing-item[data-file-type="notebook"]',
                rank: 0
            });
        }
    }
    /*
      Mutable AI manager extension dispose.
    */
    dispose() {
        var _a, _b;
        (_a = this.mutableAiMainMenu) === null || _a === void 0 ? void 0 : _a.dispose();
        (_b = this._processFilePointer) === null || _b === void 0 ? void 0 : _b.dispose();
    }
    /**
     * A promise that resolves when the settings have been loaded.
     */
    get ready() {
        return this._ready.promise;
    }
    /**
     * Mutable AI manager change extension according to settings.
     */
    _mutableAISettingsChanged() {
        var _a;
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            this.initializePlugin();
        }
        else {
            this.dispose();
        }
    }
}
